// java wrapper for vtkContinuousValueWidget object
//

package vtk;
import vtk.*;

public class vtkContinuousValueWidget extends vtkAbstractWidget
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetRepresentation_2(vtkContinuousValueWidgetRepresentation id0);
  public void SetRepresentation(vtkContinuousValueWidgetRepresentation id0)
    { SetRepresentation_2(id0); }

  private native long GetContinuousValueWidgetRepresentation_3();
  public vtkContinuousValueWidgetRepresentation GetContinuousValueWidgetRepresentation() {
    long temp = GetContinuousValueWidgetRepresentation_3();

    if (temp == 0) return null;
    return (vtkContinuousValueWidgetRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native double GetValue_4();
  public double GetValue()
    { return GetValue_4(); }

  private native void SetValue_5(double id0);
  public void SetValue(double id0)
    { SetValue_5(id0); }

  public vtkContinuousValueWidget() { super(); }

  public vtkContinuousValueWidget(long id) { super(id); }

}
